@@ -10,12 +10,8 @@ from mirai import exceptions
 
 
 async def async_(obj):
-    """将一个对象包装为 `Awaitable`。
-    """
-    if inspect.isawaitable(obj):
-        return await obj
-    else:
-        return obj
+    """将一个对象包装为 `Awaitable`。"""
+    return (await obj) if inspect.isawaitable(obj) else obj
 
 
 async def async_with_exception(obj):
@@ -36,18 +32,27 @@ class PriorityDict(Generic[T]):
         self._priorities = {}
 
     def add(self, priority: int, value: T) -> None:
-        """增加一个元素。"""
+        """增加一个元素。
+
+        Args:
+            priority: 优先级，小者优先。
+            value: 元素。
+        """
         self._data[priority].add(value)
         self._priorities[value] = priority
 
     def remove(self, value: T) -> None:
-        """移除一个元素。"""
+        """移除一个元素。
+
+        Args:
+            value: 元素。
+        """
         priority = self._priorities.get(value)
         if priority is None:
             raise KeyError(value)
-        else:
-            self._data[priority].remove(value)
-            del self._priorities[value]
+
+        self._data[priority].remove(value)
+        del self._priorities[value]
 
     def __iter__(self):
         if self._data:
@@ -57,14 +62,13 @@ class PriorityDict(Generic[T]):
             yield from cast(List[Set[T]], ())
 
 
-def KMP(string, pattern, count: int = 1) -> List[int]:
+def kmp(string, pattern, count: int = 1) -> List[int]:
     """KMP算法。
 
-    `string` 待匹配字符串。
-
-    `pattern` 模式字符串。
-
-    `count` 至多匹配的次数。
+    Args:
+        string: 待匹配字符串。
+        pattern: 模式字符串。
+        count (int): 至多匹配的次数。
     """
     if len(string) < len(pattern) or count < 1:
         return []
@@ -83,10 +87,10 @@ def KMP(string, pattern, count: int = 1) -> List[int]:
     # 开始匹配。
     matches = []
     j = 0
-    for i in range(0, len(string)):
-        while j > 0 and pattern[j] != string[i]:
+    for i, current in enumerate(string):
+        while j > 0 and pattern[j] != current:
             j = next_array[j - 1]
-        if pattern[j] == string[i]:
+        if pattern[j] == current:
             j += 1
         if j == len(pattern):
             matches.append(i - j + 1)
@@ -129,7 +133,6 @@ class Singleton(metaclass=SingletonMetaclass):
             _instance.__init__(*args, **kwargs)
             cls._instance = _instance
             return _instance
-        elif cls._args == (args, kwargs):
+        if cls._args == (args, kwargs):
             return cls._instance
-        else:
-            raise RuntimeError(f"只能创建 {cls.__name__} 的一个实例！")
+        raise RuntimeError(f"只能创建 {cls.__name__} 的一个实例！")
